@@ -43,7 +43,6 @@
 #include "photos-export-dialog.h"
 #include "photos-export-notification.h"
 #include "photos-filterable.h"
-#include "photos-gom-miner.h"
 #include "photos-item-manager.h"
 #include "photos-main-window.h"
 #include "photos-properties-dialog.h"
@@ -633,6 +632,7 @@ static gboolean
 photos_application_create_window (PhotosApplication *self)
 {
   gboolean gexiv2_initialized;
+  gboolean gexiv2_registered_namespace;
 
   if (self->main_window != NULL)
     return TRUE;
@@ -640,6 +640,9 @@ photos_application_create_window (PhotosApplication *self)
   gexiv2_initialized = gexiv2_initialize ();
   g_return_val_if_fail (gexiv2_initialized, FALSE);
 
+  gexiv2_registered_namespace = gexiv2_metadata_register_xmp_namespace ("http://www.gnome.org/xmp", "gnome");
+  g_return_val_if_fail (gexiv2_registered_namespace, FALSE);
+
   g_return_val_if_fail (photos_application_sanity_check_gegl (self), FALSE);
 
   self->main_window = photos_main_window_new (GTK_APPLICATION (self));
@@ -2019,6 +2022,29 @@ photos_application_new (void)
 }
 
 
+GomMiner *
+photos_application_get_miner (PhotosApplication *self, const gchar *provider_type)
+{
+  GList *l;
+  GomMiner *ret_val = NULL;
+
+  for (l = self->miners; l != NULL; l = l->next)
+    {
+      GomMiner *miner = GOM_MINER (l->data);
+      const gchar *miner_provider_type;
+
+      miner_provider_type = g_object_get_data (G_OBJECT (miner), "provider-type");
+      if (g_strcmp0 (provider_type, miner_provider_type) == 0)
+        {
+          ret_val = miner;
+          break;
+        }
+    }
+
+  return ret_val;
+}
+
+
 GList *
 photos_application_get_miners_running (PhotosApplication *self)
 {
