@@ -35,36 +35,12 @@ G_BEGIN_DECLS
   (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
    PHOTOS_TYPE_ORGANIZE_COLLECTION_DIALOG, PhotosOrganizeCollectionDialog))
 
-#define PHOTOS_ORGANIZE_COLLECTION_DIALOG_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_CAST ((klass), \
-   PHOTOS_TYPE_ORGANIZE_COLLECTION_DIALOG, PhotosOrganizeCollectionDialogClass))
-
 #define PHOTOS_IS_ORGANIZE_COLLECTION_DIALOG(obj) \
   (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
    PHOTOS_TYPE_ORGANIZE_COLLECTION_DIALOG))
 
-#define PHOTOS_IS_ORGANIZE_COLLECTION_DIALOG_CLASS(klass) \
-  (G_TYPE_CHECK_CLASS_TYPE ((klass), \
-   PHOTOS_TYPE_ORGANIZE_COLLECTION_DIALOG))
-
-#define PHOTOS_ORGANIZE_COLLECTION_DIALOG_GET_CLASS(obj) \
-  (G_TYPE_INSTANCE_GET_CLASS ((obj), \
-   PHOTOS_TYPE_ORGANIZE_COLLECTION_DIALOG, PhotosOrganizeCollectionDialogClass))
-
-typedef struct _PhotosOrganizeCollectionDialog        PhotosOrganizeCollectionDialog;
-typedef struct _PhotosOrganizeCollectionDialogClass   PhotosOrganizeCollectionDialogClass;
-typedef struct _PhotosOrganizeCollectionDialogPrivate PhotosOrganizeCollectionDialogPrivate;
-
-struct _PhotosOrganizeCollectionDialog
-{
-  GtkDialog parent_instance;
-  PhotosOrganizeCollectionDialogPrivate *priv;
-};
-
-struct _PhotosOrganizeCollectionDialogClass
-{
-  GtkDialogClass parent_class;
-};
+typedef struct _PhotosOrganizeCollectionDialog      PhotosOrganizeCollectionDialog;
+typedef struct _PhotosOrganizeCollectionDialogClass PhotosOrganizeCollectionDialogClass;
 
 GType               photos_organize_collection_dialog_get_type           (void) G_GNUC_CONST;
 
